@@ -9,6 +9,7 @@ class DjangoWatchTowerHandler(watchtower_logging.watchtower_logging.WatchTowerHa
         token = getattr(settings, 'WT_TOKEN', None)
         protocol = getattr(settings, 'WT_PROTOCOL', 'https')
         dev = getattr(settings, 'WT_DEV', False)
+        timeout = getattr(settings, 'WT_TIMEOUT', 1.0)
 
         super().__init__(
             beam_id=settings.WT_BEAM_ID,
@@ -16,4 +17,5 @@ class DjangoWatchTowerHandler(watchtower_logging.watchtower_logging.WatchTowerHa
             protocol=protocol,
             host=settings.WT_HOST,
             flush_interval=-1,
-            dev=dev)
\ No newline at end of file
+            dev=dev,
+            timeout=timeout)
\ No newline at end of file
