@@ -132,7 +132,8 @@ def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, prot
 
     if send:
         if use_threading is None:
-            if (not os.environ.get('GCP_PROJECT') is None) and (not os.environ.get('FUNCTION_NAME') is None):
+            if ((not os.environ.get('GCP_PROJECT') is None) and (not os.environ.get('FUNCTION_NAME') is None)) or \
+                    ((not os.environ.get('FUNCTION_TARGET') is None) and (not os.environ.get('K_SERVICE') is None)):
                 # Cloud Functions does not allow threading, so set to negative flush interval -> blocking calls
                 flush_interval = -1.0
             else:
